/////////////////////////////////////////////////////////////////////////////
// Project:     wxSQuery
// Purpose:     SQL query tool for the SQLite3 library
// Name:        wxchainlogtextctrl.h
// Author:      Daniel Nell
// Created:     2008/09/26
// Copyright:   (c) Daniel Nell
// Licence:     wxWindows licence
// Modified by:
/////////////////////////////////////////////////////////////////////////////

#ifndef __WXCHAINLOGTEXTCTRL_H
#define __WXCHAINLOGTEXTCTRL_H

/////////////////////////////////////////////////////////////////////////////
//  Class wxChainLogTextCtrl
//
/// \brief ...
///
/// ...
class wxChainLogTextCtrl : public wxLogGui
{
  public:
    /// \brief Standard constructor.
    ///
    /// \param poTextctrl    a pointer to a wxTextCtrl object, that is used as an addition
    /// \param nMaxLevel     refence log level for to suppress messages with higher level,
    ///                      defaults to 2 (errors)
    wxChainLogTextCtrl( wxTextCtrl *poTextctrl, wxLogLevel nMaxLevel= 2 )
    {
        // Save log level.
        m_nMaxLevel= nMaxLevel;

        // Set this object as the new log target.
        wxLog::SetActiveTarget( this );

        // Chain the log to the wxTextCtrl object.
        new wxLogChain( new wxLogTextCtrl( poTextctrl ) );
    }


    /// \brief Internally called function to process the log message.
    ///
    /// Suppress the log output if the given log level is higher then m_nMaxLevel.
    /// So it is possible to get only error messages shown in the normal dialog
    /// window while anything else is logged to the chained wxTextCtrl object.
    ///
    /// \param oLevel        log level
    /// \param pszMessage    message to log
    /// \param nTimestamp    timestamp of the message
    virtual void DoLog( wxLogLevel nLevel, const wxChar *pszMessage, time_t nTimestamp )
    {
        // Show message only if the log level is lower or equal to the reference value.
        if( nLevel <= m_nMaxLevel )
        {
            // Show message using parent function.
            wxLogGui::DoLog( nLevel, pszMessage, nTimestamp );
        }
    }

  protected:
    wxLogLevel m_nMaxLevel;
};

#endif // __WXCHAINLOGTEXTCTRL_H
